@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 use feature qw(state);
 
-our $VERSION = '0.2';
+our $VERSION = '0.3';
 
 use Carp qw(croak);
 use English qw(-no_match_vars);
@@ -99,6 +99,15 @@ sub _must_validate {
     return 1;
 }
 
+sub DESTROY {
+    my ( $self ) = @ARG;
+
+    # this is to ensure that the objects are destroyed in a consistent order.
+    for my $pkg ( sort keys %{ $self->{_packages} } ) {
+        delete $self->{_packages}{$pkg};
+    }
+}
+
 1;
 
 __END__
@@ -111,7 +120,7 @@ Test::MockPackages - Mock external dependencies in tests
 
 =head1 VERSION
 
-Version 0.2
+Version 0.3
 
 =head1 SYNOPSIS
 
@@ -339,6 +348,6 @@ Written by Tom Peters <tpeters at synacor.com>.
 
 =head1 COPYRIGHT
 
-Copyright (c), Synacor, Inc., 2016
+Copyright (c) 2016 Synacor, Inc.
 
 =cut
