@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.10';
+our $VERSION = '0.3';
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ Test::MockPackages::Mock - handles mocking of individual methods and subroutines
 
 =head1 VERSION
 
-Version 0.10
+Version 0.3
 
 =head1 SYNOPSIS
 
@@ -65,7 +65,6 @@ use Lingua::EN::Inflect qw(PL);
 use List::Util qw(max);
 use Scalar::Util qw(looks_like_number weaken);
 use Storable qw(dclone);
-use Test::Deep qw(cmp_deeply);
 use Test::More;
 use parent qw(Test::Builder::Module);
 
@@ -113,10 +112,7 @@ sub new {
 
 Will ensure that the subroutine/method has been called C<$called> times. This method cannot be used in combination with C<never_called()>.
 
-Setting C<$called> to C<-1> will prevent invocation count checks.
-
 You can combined this method with C<expects()> and/or C<returns()> to support repeated values. For example:
-
     $m->expects($arg1, $arg2)
       ->expects($arg1, $arg2)
       ->expects($arg1, $arg2)
@@ -124,13 +120,13 @@ You can combined this method with C<expects()> and/or C<returns()> to support re
       ->expects($arg1, $arg2);
 
 can be simplified as:
-
     $m->expects($arg1, $arg2)
       ->called(5);
 
-By default, this package will ensure that a mocked subroutine/method is called the same number of times that C<expects()> and/or C<returns()> has been setup for. For example, if you call C<expects()> three times, then when this object is destroyed we will ensure the mocked subroutine/method was called exactly three times, no more, no less.
+By default, this package will ensure that a mocked subroutine/method is called the same number of times that C<expects()> and/or C<returns()> has been setup for.
+You only need to use this method if you don't setup any expects or returns, or to simplify repeated values like what was shown up above.
 
-Therefore, you only need to use this method if you don't setup any expects or returns, or to simplify repeated values like what was shown up above.
+C<-1> is a special value which will ensure that have the test ignore the check on how many times a subroutine/method was called.
 
 Return value: Returns itself to support the fluent interface.
 
@@ -183,20 +179,13 @@ sub is_method {
 =head2 expects( Any @expects ) : Test::MockPackage::Mock, Throws '...'
 
 Ensures that each invocation has the correct arguments passed in. If the subroutine/method will be called multiple times, you can call C<expects()> multiple times. If
-the same arguments are expected repeatedly, you can use this in conjunction with C<called()>. See L<called()> for further information.
+the same expectation will be used repeatedly, you can use this in conjunction with C<called()>. See L<called()> for more information.
 
 If you are mocking a method, be sure to call C<is_method()> at some point.
 
 When the C<Test::MockPackages::Mock> object goes out of scope, we'll test to make sure that the subroutine/method was called the correct number of times based on the number
 of times that C<expects()> was called, unless C<called()> is specified.
 
-The actual comparison is done using Test::Deep::cmp_deeply(), so you can use any of the associated helper methods to do a comparison.
-
-  use Test::Deep qw(re);
-
-  $m->mock( 'my_sub' )
-    ->expects( re( qr/^\d{5}\z/ ) );
-
 Return value: Returns itself to support the fluent interface.
 
 =cut
@@ -217,15 +206,7 @@ If this method will always return the same values, you can call C<returns()> onc
 When the C<Test::MockPackages::Mock> object goes out of scope, we'll test to make sure that the subroutine/method was called the correct number of times based on the number
 of times that C<expects()> was called, unless C<called()> is specified.
 
-Values passed in will be returned verbatim. A deep clone is also performed to accidental side effects aren't tested. If you don't want to have your data deep cloned, you can use returns_code.
-
- $m->mock('my_sub')
-   ->returns( $data_structure ); # $data_structure will be deep cloned using Storable::dclone();
-
- $m->mock('my_sub')
-   ->returns( returns_code { $data_structure } ); # $data_structure will not be cloned.
-
-If you plan on returning a L<Test::MockObject> object, you will want to ensure that it's not deep cloned (using returns_code) because that module uses the object's address to keep track of mocked methods (instead of using attributes).
+Values passed in will be returned verbatim. A deep clone is also performed to accidental side effects aren't tested.
 
 C<wantarray> will be used to try and determine if a list or a single value should be returned. If C<@returns> contains a single element and C<wantarray> is false, the value at index 0 will be returned. Otherwise,
 a list will be returned.
@@ -249,12 +230,7 @@ sub returns {
     my ( $self, @returns ) = @ARG;
 
     # dclone will remove the bless on the CodeRef.
-    if (@returns == 1 && do {
-            local $EVAL_ERROR = undef;
-            eval { $returns[ 0 ]->isa( 'Test::MockPackages::Returns' ) };
-        }
-        )
-    {
+    if ( @returns == 1 && eval { $returns[ 0 ]->isa( 'Test::MockPackages::Returns' ) } ) {
         push @{ $self->{_returns} }, \@returns;
     }
     else {
@@ -289,16 +265,13 @@ sub _initialize {
     my $mock = sub {
         my ( @got ) = @ARG;
 
-        # used for returns_code
-        my @original_args = @got;
-
         # _invoke_count keeps track of how many times this subroutine/method was called
         my $invoke_number = ++$self->{_invoke_count};
 
         # $i is the current invocation
         my $i = $invoke_number - 1;
 
-        # The first value passed into the method is the object itself. Ignore that.
+        # the first value passed into the method is the object itself. ignore that.
         if ( $self->{_is_method} ) {
             shift @got;
         }
@@ -324,7 +297,7 @@ sub _initialize {
             }
 
             local $Test::Builder::Level = $Test::Builder::Level + 1;    ## no critic (Variables::ProhibitPackageVars)
-            cmp_deeply( \@got, $expected, "$self->{_full_name} expects is correct" );
+            is_deeply( \@got, $expected, "$self->{_full_name} expects is correct" );
         }
 
         # setup the return values
@@ -352,13 +325,8 @@ sub _initialize {
             return;
         }
 
-        if (@returns == 1 && do {
-                local $EVAL_ERROR = undef;
-                eval { $returns[ 0 ]->isa( 'Test::MockPackages::Returns' ) };
-            }
-            )
-        {
-            return $returns[ 0 ]->( @original_args );
+        if ( @returns == 1 && eval { $returns[ 0 ]->isa( 'Test::MockPackages::Returns' ) } ) {
+            return $returns[ 0 ]->( @got );
         }
 
         # return the first element if only one return defined and a wantarray is false.
